(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     23565,        594]*)
(*NotebookOutlinePosition[     24214,        617]*)
(*  CellTagsIndexPosition[     24170,        613]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(deg = 4; \ nVar = 8; \n<< PATH/Defns.txt; \n<< PATH/SnDefns.txt; 
    \n<< PATH/S8Defns.txt; \n<< PATH/FaK2.txt; \n<< PATH/FaK3.txt; 
    \n<< PATH/TaK.txt; \n<< PATH/GammaK.txt; \)], "Input"],

Cell["Iteration set-up", "Text",
  FontFamily->"Helvetica",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[{
    \(\(norm[0]\)[x_] := x; \n\(norm[1]\)[x_] := x/x[\([1]\)]\), 
    \(\(norm[2]\)[x_]\  := x/x[\([2]\)]\), 
    \(\(norm[3]\)[x_]\  := x/x[\([3]\)]\), 
    \(\(norm[4]\)[x_]\  := x/x[\([4]\)]\), 
    \(\(norm[5]\)[x_]\  := x/x[\([5]\)]\), 
    \(\(norm[6]\)[x_]\  := x/x[\([6]\)]; \n\(norm[7]\)[x_]\  := x/x[\([7]\)]; 
    \n\(norm[8]\)[x_]\  := x/x[\([8]\)]; \n\niterPrecision = 150; \n\n
    NumIterNorm[f_, \ x_, m_, \ n_]\  := 
      SetPrecision[\n\ NestList[Composition[norm[m], \ f], \ x, \ n], \n
        iterPrecision]; \)}], "Input",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Evaluation functions for the invariant forms, root-selector and resolvent\
\>", "Text",
  FontFamily->"Helvetica",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[{
    \(RaKChooseEval[x_]\  := FuncEval[RaKChoose, {s}, {x}]\), 
    \(JaKChooseEval[x_]\  := FuncEval[JaKChoose, Wvec[nVar], x]\)}], "Input"],

Cell["General octic", "Text",
  FontFamily->"Helvetica",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(P[x_, A_]\  := \ \n\t
      \(Sum[a[i]*x^\((nVar - i)\), {i, 0, nVar}] /. \n\t\ta[0] -> 1\) /. 
        Table[a[i] -> A[\([i]\)], {i, nVar}]\), 
    \(P[x, Array[a, nVar]]\)}], "Input"],

Cell[BoxData[
    \(x\^8 + x\^7\ a[1] + x\^6\ a[2] + x\^5\ a[3] + x\^4\ a[4] + x\^3\ a[5] + 
      x\^2\ a[6] + x\ a[7] + a[8]\)], "Output"]
}, Open  ]],

Cell["\<\
Linear Tschirnhaus transformation to reduce general
octic to \"standard\" octic--degree-7 term = 0\
\>", "Text",
  FontFamily->"Helvetica",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(GenToSt[y_, a1_]\  := \ y\  - \ a1/nVar\)], "Input"],

Cell["\<\
Select the coefficients of  a general octic
   a) Random choice
   b) Specified\
\>", "Text",
  FontFamily->"Helvetica",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\( (*a*) \n
    \(GenCoeffChoose\  = \ 
      Table[\n\t\t
        Random[Complex, 100*{\(-1\) - I, 1 + I}, iterPrecision + 100], {i, 
          nVar}]; \)\)\)], "Input"],

Cell[BoxData[
    \(\( (*b*) \n
    \(GenCoeffChoose\  = \ {1, \(-1\), 1, \(-1\), 1, \(-1\), 1, \(-1\)}; 
    \)\)\)], "Input"],

Cell["\<\
1) The chosen octic
2) The corresponding chosen standard octic
3) The corrresponding coefficients of the standard octic\
\>", "Text",
  FontFamily->"Helvetica",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*2*) \nGenChoose\  = \ P[x, GenCoeffChoose]; \n\t\t
    Chop[N[GenChoose]]\n (*3*) \), 
    \(StChoose\  = \ \nCollect[P[GenToSt[y, a[1]], GenCoeffChoose], y]; \n\t\t
    Chop[N[StChoose]]\n (*4*) \), 
    \(StCoeffChoose\  = \ \n
      Table[Coefficient[StChoose, y, nVar - i], {i, 2, nVar}]; \n\t\t
    Chop[N[StCoeffChoose]]\)}], "Input"],

Cell[BoxData[
    \(\((\(1.03781085795852878`\[InvisibleSpace]\) - 47.9433331246303495`\ I)
        \) - \((\(3.40402671533653444`\[InvisibleSpace]\) + 
            65.7200910975821717`\ I)\)\ x + 
      \((\(20.5741912132075688`\[InvisibleSpace]\) + 11.8853885482151412`\ I)
          \)\ x\^2 + 
      \((\(42.973492287533892`\[InvisibleSpace]\) - 10.1293751279714161`\ I)
          \)\ x\^3 + 
      \((\(13.3530303283531059`\[InvisibleSpace]\) + 14.7429946214787088`\ I)
          \)\ x\^4 + 
      \((\(56.6953028726361196`\[InvisibleSpace]\) + 70.9136850840798516`\ I)
          \)\ x\^5 + 
      \((\(40.379456127015576`\[InvisibleSpace]\) + 91.6766827949362195`\ I)
          \)\ x\^6 + 
      \((\(3.76064286812037362`\[InvisibleSpace]\) - 98.1196917402274948`\ I)
          \)\ x\^7 + x\^8\)], "Output"],

Cell[BoxData[
    \(\((\(-3.5227771048783909`*^9\) - 1.41240395801782847`*^9\ I)\) - 
      \((6.91758575112681128`*^8 - 1.98829969413275975`*^9\ I)\)\ y + 
      \((4.76316658634316514`*^8 + 1.41095037609856106`*^8\ I)\)\ y\^2 + 
      \((1.5340456913142102`*^7 - 6.24642487237092236`*^7\ I)\)\ y\^3 - 
      \((4.78980138977491876`*^6 + 937682.37158025034`\ I)\)\ y\^4 - 
      \((\(30551.8795086071293`\[InvisibleSpace]\) - 208514.253763246282`\ I)
          \)\ y\^5 + 
      \((\(4246.2119753088956`\[InvisibleSpace]\) + 414.545661889360328`\ I)
          \)\ y\^6 + y\^8\)], "Output"],

Cell[BoxData[
    \({\(4246.2119753088956`\[InvisibleSpace]\) + 414.545661889360328`\ I, 
      \(-30551.8795086071293`\) + 208514.253763246282`\ I, 
      \(-4.78980138977491876`*^6\) - 937682.37158025034`\ I, 
      1.5340456913142102`*^7 - 6.24642487237092236`*^7\ I, 
      4.76316658634316514`*^8 + 1.41095037609856106`*^8\ I, 
      \(-6.91758575112681128`*^8\) + 1.98829969413275975`*^9\ I, 
      \(-3.5227771048783909`*^9\) - 1.41240395801782847`*^9\ I}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(TextForm
    \`\(\(\(1)\)\ Transformation\ of\ coefficients\ from\ standard\ octic\ \n
            \ \ \tto\ \ 6 - parameter\ S\_8\ resolvent\n2)\)\ Linear\ 
          Tschirnhaus\ transformation\ of\ octic\ \n
        \ \ \tto\ \ 7 - parameter\ S\_8\ resolvent\n3)\)\ Obtain\ K\ 
      parameters\ and\ "reduction"\ parameter\ \[Lambda]\)], "Text",
  FontFamily->"Helvetica",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*1*) \n
    StToS8a7CoeffTrf\  = 
      \n{\(-\(\(9\ b[3]\^2\)\/\(8\ b[2]\^3\)\)\), 
        \(b[2]\^2 - 2\ b[4]\)\/\(2\ b[2]\^2\), 
        \(5\ \((b[2]\ b[3] - b[5])\)\)\/\(6\ b[2]\ b[3]\), 
        \(2\ b[2]\^3 - 3\ b[3]\^2 - 6\ b[2]\ b[4] + 6\ b[6]\)\/\(8\ 
            b[2]\^3\), 
        \(7\ \((b[2]\^2\ b[3] - b[3]\ b[4] - b[2]\ b[5] + b[7])\)\)\/\(10\ 
            b[2]\ \((b[2]\ b[3] - b[5])\)\), 
        \(1\/\(8\ b[2]\^4\)\) 
          \((b[2]\^4 - 4\ b[2]\ b[3]\^2 - 4\ b[2]\^2\ b[4] + 2\ b[4]\^2 + 
              4\ b[3]\ b[5] + 4\ b[2]\ b[6] - 4\ b[8])\), 
        \(-\(\(3\ b[3]\)\/\(16\ b[2]\)\)\)}; \n (*2*) \n
    S8a7ToStTrf[t_, \ \[Lambda]_]\  := \ \ \[Lambda]*t\n (*3*) \), 
    \(KChoose\  = \n
      Drop[FuncEval[StToS8a7CoeffTrf, Table[b[i], {i, 2, nVar}], StCoeffChoose
          \n], {nVar - 1}]; \nN[KChoose]\), 
    \(\[Lambda]Choose\  = \ \n
      \(FuncEval[StToS8a7CoeffTrf, Table[b[i], {i, 2, nVar}], StCoeffChoose]
          \)[\([nVar - 1]\)]; \nN[\[Lambda]Choose]\)}], "Input"],

Cell[BoxData[
    \({\(0.643375175893306483`\[InvisibleSpace]\) - 
        0.000632582008896128655`\ I, 
      \(0.768139411231152902`\[InvisibleSpace]\) - 
        0.000352872225713922826`\ I, 
      \(0.892948499416355545`\[InvisibleSpace]\) - 
        0.000118253126097789952`\ I, 
      \(0.670360649434845257`\[InvisibleSpace]\) - 
        0.000494561814253173803`\ I, 
      \(0.875525034234077459`\[InvisibleSpace]\) - 
        0.00020917792853294097`\ I, 
      \(0.586648992943650604`\[InvisibleSpace]\) - 
        0.000578326131414920574`\ I}\)], "Output"],

Cell[BoxData[
    \(\(0.44594021260859904`\[InvisibleSpace]\) - 9.25090065913396486`\ I\)], 
  "Output"]
}, Open  ]],

Cell[BoxData[
    \(TextForm\`\(\(\(\(\(\(Evaluate\ at\ "chosen"\ value\ of\ \ K\n
                                \ \ 1)\)\ K - 
                            parametrized\ reversed\ symmetric\ matrix\ T\_K\n
                          \ \ 2)\)\ basic\ invariants\ \[CapitalPhi]\_2\ and\ 
                        \[CapitalPhi]\_3\n
                      \ \ 3)\)\ basic\ equivariants\ \[Phi]\_1, \ \[Phi]\_2, 
                  \ and\ \ \[Phi]\_4\t\n
                  \ \ 4)\)\ the\ map\ \(g\_\(4\_K\)\) \((w)\)\n
              \ \ 5)\) the\ resolvent\ \(R\_K\) \((s)\)\n
          \ \ 6)\) the\ root - selector\ \(J\_K\) \((w)\)\)], "Text",
  FontFamily->"MS Sans Serif",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*1*) \n
    TaKChoose\  = \ 
      Expand[\((TaK /. Table[K[i] -> KChoose[[i]], {i, nVar - 2}])\)]; \n
    TaKDetChoose\  = \ Det[TaKChoose]; \n
    TaKInvChoose = Cofactor[TaKChoose]/TaKDetChoose; \n\n (*2*) \n
    PhiKChoose[2]\  = \ 
      Expand[FaK[2] /. Table[K[i] -> KChoose[[i]], {i, nVar - 2}]]; \n
    PhiKChoose[3]\  = \ 
      Expand[FaK[3] /. Table[K[i] -> KChoose[[i]], {i, nVar - 2}]]; \n
    GaKChoose[4] = 
      Expand[\((KChoose[[1]]/TaKDetChoose)\)*
          Det[\n\ \ \ \ 
            BH[PhiKChoose[2], PhiKChoose[3], PhiKChoose[3]\n
              \ \ \ \ \ \ \ \ \ , Wvec[nVar]]\ ]]; \n
    PhiKChoose[4] = 
      Expand[1\/576\ \((72\ FF[2]\^2 + GG[4])\) /. \n
          \t\t{FF[2] -> PhiKChoose[2], GG[4] -> GaKChoose[4]}]; \n
    GaKChoose[5] = 
      Expand[\((1/TaKDetChoose)\)*
          Det[\n\ \ \ \ 
            BH[PhiKChoose[2], PhiKChoose[3], PhiKChoose[4]\n\t\t\t\t, 
              Wvec[nVar]]\ ]]; \n
    PhiKChoose[5] = 
      Expand[1\/768\ \((96\ FF[2]\ FF[3] + GG[5])\) /. \n
          \t\t{FF[2] -> PhiKChoose[2], FF[3] -> PhiKChoose[3], \n\t\t\t\t
            GG[5] -> GaKChoose[5]}]; \n\n (*3*) \n
    phiKChoose[1]\  = 
      Expand[\((\(-8\)/2)\)*
          TaKInvChoose . \n\t\treDiff[PhiKChoose[2], Wvec[nVar]]]; \n
    phiKChoose[2]\  = 
      Expand[\((\(-8\)/3)\)*
          TaKInvChoose . \n\t\treDiff[PhiKChoose[3], Wvec[nVar]]]; \n
    phiKChoose[4]\  = 
      Expand[\((\(-8\)/5)\)*
          TaKInvChoose . \n\t\treDiff[PhiKChoose[5], Wvec[nVar]]]; \n
    \n (*4*) \n
    g4KChoose = \ 
      Expand[\(84\ ff[4] - 9\ ff[2]\ SS[2] - 2\ ff[1]\ SS[3]\)\/172032 /. \n
          Flatten[{Table[SS[i] -> PhiKChoose[i], {i, 2, nVar}], \n
              \t\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ 
              Table[ff[i] -> phiKChoose[i], {i, nVar - 1}]}]]; \n\n (*5*) \n
    RaK\  = s\^8 + \(512\ s\^5\)\/\(3\ K[1]\) - \(32\ s\^6\)\/K[1] - 
        \(512\ s\^4\ \((\(-1\) + 2\ K[2])\)\)\/K[1]\^2 + 
        \(16384\ s\^3\ \((\(-5\) + 6\ K[3])\)\)\/\(15\ K[1]\^2\) + 
        \(16384\ s\^2\ \((\(-3\) + 8\ K[1] + 18\ K[2] - 24\ K[4])\)\)\/\(9\ 
            K[1]\^3\) - 
        \(262144\ s\ 
            \((\(-35\) + 70\ K[2] + 84\ K[3] - 120\ K[3]\ K[5])\)\)\/\(105\ 
            K[1]\^3\) + 
        \(1\/\(45\ K[1]\^4\)\) 
          \((131072\ 
              \((15 - 160\ K[1] - 180\ K[2] + 180\ K[2]\^2 + 
                  384\ K[1]\ K[3] + 480\ K[4] - 720\ K[6])\))\); \n
    RaKChoose\  = \ RaK /. Table[K[i] -> KChoose[[i]], {i, nVar - 2}]; \n
    N[RaKChoose]\n\n (*6*) \), 
    \(\(JaKChoose\  = \ 
      \[CapitalGamma]aK/\((48*FaK[2])\) /. \n\t\t
        Table[K[i] -> KChoose[[i]], {i, nVar - 2}]; \)\)}], "Input"],

Cell[BoxData[
    \(\((\(-70.1046072550318566`\) + 0.282536782707117026`\ I)\) + 
      \((\(360.143782671885226`\[InvisibleSpace]\) - 0.849427903770214953`\ I)
          \)\ s - \((
          \(787.102587362450023`\[InvisibleSpace]\) - 
            0.803105136367864425`\ I)\)\ s\^2 + 
      \((\(943.862047052389918`\[InvisibleSpace]\) - 
            0.0161946274353360646`\ I)\)\ s\^3 - 
      \((\(663.333410866113037`\[InvisibleSpace]\) + 0.431462349244703347`\ I)
          \)\ s\^4 + 
      \((\(265.267464572784295`\[InvisibleSpace]\) + 0.260817376737056516`\ I)
          \)\ s\^5 - 
      \((\(49.7376496073970564`\[InvisibleSpace]\) + 
            0.0489032581381980957`\ I)\)\ s\^6 + s\^8\)], "Output"]
}, Open  ]],

Cell["\<\
Iteration
Map\
\>", "Text",
  FontFamily->"Helvetica",
  FontSize->16,
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(fKIter\  = g4KChoose; \n
    fKIterMap[x_] := FuncEval[fKIter, Wvec[nVar], x]\)], "Input"],

Cell["Random start  (normalized)", "Text",
  FontFamily->"Helvetica",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(pRandomComplex[m_]\  := \n
      \(norm[1]\)[
        Table[Random[\n\ Complex, {\(-\((1 + I)\)\), 1 + I}, iterPrecision], {
            i, nVar - 1}\n]]\), 
    \(pStart = pRandomComplex[1]; \nN[pStart]\)}], "Input"],

Cell[BoxData[
    \({\(1.`\[InvisibleSpace]\) + 0.`\ I, 
      \(-1.70038896037063107`\) + 0.412791489528122035`\ I, 
      \(-0.862683742109163986`\) - 0.142070211139364621`\ I, 
      \(0.312449987148978092`\[InvisibleSpace]\) + 0.968848848645785309`\ I, 
      \(-0.835373933223254105`\) + 1.71675467704879514`\ I, 
      \(0.627594429186545887`\[InvisibleSpace]\) - 1.25384322868580033`\ I, 
      \(0.668803892811888367`\[InvisibleSpace]\) - 1.13852786785817428`\ I}
      \)], "Output"]
}, Open  ]],

Cell["Iteration begins", "Text",
  FontFamily->"Helvetica",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],

Cell[CellGroupData[{

Cell[BoxData[
    \(normVar = 1; \nnumIt = 4; \n\n
    fKIt = NumIterNorm[fKIterMap, pStart, normVar, numIt]; \n\n
    N[Take[fKIt, {\(-numIt\), \(-1\)}]]\)], "Input"],

Cell[BoxData[
    \({{\(1.`\[InvisibleSpace]\) + 3.8614813301715948`*^-150\ I, 
        \(4.55388809819265194`\[InvisibleSpace]\) + 0.951888678585942571`\ I, 
        \(-13.6194101422147917`\) + 3.67679765678988079`\ I, 
        \(-126.454815700869938`\) - 37.1350153025158613`\ I, 
        \(-115.767235685603564`\) - 208.834910781393734`\ I, 
        \(274.56761939601364`\[InvisibleSpace]\) - 86.5191648346348962`\ I, 
        \(-17.1318745926536042`\) + 284.309044431793402`\ I}, {
        \(1.`\[InvisibleSpace]\) - 3.54722752506094796`*^-135\ I, 
        \(20.9425633944097633`\[InvisibleSpace]\) + 
          0.0402516850969299433`\ I, 
        \(243.73401852929768`\[InvisibleSpace]\) + 0.855955275727788134`\ I, 
        \(1703.54960859655069`\[InvisibleSpace]\) + 8.15539995676904538`\ I, 
        \(7120.18528977772291`\[InvisibleSpace]\) + 40.5261412671802911`\ I, 
        \(16987.5215927488181`\[InvisibleSpace]\) + 110.090249588027755`\ I, 
        \(14554.9862559129783`\[InvisibleSpace]\) + 
          93.7775565608684757`\ I}, {
        \(1.`\[InvisibleSpace]\) - 7.05906024038015278`*^-135\ I, 
        \(20.9754112569990214`\[InvisibleSpace]\) + 
          0.0349312644692749696`\ I, 
        \(244.458519151801656`\[InvisibleSpace]\) + 0.73177566997855159`\ I, 
        \(1710.71745795204321`\[InvisibleSpace]\) + 6.83917985485586754`\ I, 
        \(7157.70539048449094`\[InvisibleSpace]\) + 33.0469928548400737`\ I, 
        \(17092.078357952154`\[InvisibleSpace]\) + 87.1854003803397858`\ I, 
        \(14654.825828014979`\[InvisibleSpace]\) + 69.354514267840841`\ I}, {
        \(1.`\[InvisibleSpace]\) - 9.13952349080517301`*^-135\ I, 
        \(20.9754112569990214`\[InvisibleSpace]\) + 
          0.0349312644692749696`\ I, 
        \(244.458519151801656`\[InvisibleSpace]\) + 0.73177566997855159`\ I, 
        \(1710.71745795204321`\[InvisibleSpace]\) + 6.83917985485586754`\ I, 
        \(7157.70539048449094`\[InvisibleSpace]\) + 33.0469928548400737`\ I, 
        \(17092.078357952154`\[InvisibleSpace]\) + 87.1854003803397858`\ I, 
        \(14654.825828014979`\[InvisibleSpace]\) + 69.354514267840841`\ I}}
      \)], "Output"]
}, Open  ]],

Cell["Iteration continues", "Text",
  FontFamily->"Helvetica",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pCont = fKIt[\([\(-1\)]\)]; \nnormVar = 1; \nnumIt = 4; \n\n
    fKIt = NumIterNorm[fKIterMap, pCont, normVar, numIt]; \n\n
    N[Take[fKIt, {\(-numIt\), \(-1\)}]]\)], "Input"],

Cell[BoxData[
    \({{\(1.`\[InvisibleSpace]\) - 3.3430222325829435`*^-149\ I, 
        \(20.9754112569990214`\[InvisibleSpace]\) + 
          0.0349312644692749696`\ I, 
        \(244.458519151801656`\[InvisibleSpace]\) + 0.73177566997855159`\ I, 
        \(1710.71745795204321`\[InvisibleSpace]\) + 6.83917985485586754`\ I, 
        \(7157.70539048449094`\[InvisibleSpace]\) + 33.0469928548400737`\ I, 
        \(17092.078357952154`\[InvisibleSpace]\) + 87.1854003803397858`\ I, 
        \(14654.825828014979`\[InvisibleSpace]\) + 69.354514267840841`\ I}, {
        \(1.`\[InvisibleSpace]\) - 3.74707784169571489`*^-149\ I, 
        \(20.9754112569990214`\[InvisibleSpace]\) + 
          0.0349312644692749696`\ I, 
        \(244.458519151801656`\[InvisibleSpace]\) + 0.73177566997855159`\ I, 
        \(1710.71745795204321`\[InvisibleSpace]\) + 6.83917985485586754`\ I, 
        \(7157.70539048449094`\[InvisibleSpace]\) + 33.0469928548400737`\ I, 
        \(17092.078357952154`\[InvisibleSpace]\) + 87.1854003803397858`\ I, 
        \(14654.825828014979`\[InvisibleSpace]\) + 69.354514267840841`\ I}, {
        \(1.`\[InvisibleSpace]\) - 2.45908952248402012`*^-150\ I, 
        \(20.9754112569990214`\[InvisibleSpace]\) + 
          0.0349312644692749696`\ I, 
        \(244.458519151801656`\[InvisibleSpace]\) + 0.73177566997855159`\ I, 
        \(1710.71745795204321`\[InvisibleSpace]\) + 6.83917985485586754`\ I, 
        \(7157.70539048449094`\[InvisibleSpace]\) + 33.0469928548400737`\ I, 
        \(17092.078357952154`\[InvisibleSpace]\) + 87.1854003803397858`\ I, 
        \(14654.825828014979`\[InvisibleSpace]\) + 69.354514267840841`\ I}, {
        \(1.`\[InvisibleSpace]\) - 9.77579636319873657`*^-150\ I, 
        \(20.9754112569990214`\[InvisibleSpace]\) + 
          0.0349312644692749696`\ I, 
        \(244.458519151801656`\[InvisibleSpace]\) + 0.73177566997855159`\ I, 
        \(1710.71745795204321`\[InvisibleSpace]\) + 6.83917985485586754`\ I, 
        \(7157.70539048449094`\[InvisibleSpace]\) + 33.0469928548400737`\ I, 
        \(17092.078357952154`\[InvisibleSpace]\) + 87.1854003803397858`\ I, 
        \(14654.825828014979`\[InvisibleSpace]\) + 69.354514267840841`\ I}}
      \)], "Output"]
}, Open  ]],

Cell[BoxData[{
    FormBox[
    \(Look\ for\ period - 
        1\ \(convergence : \ \ 
            \(g\_\(4\_K\)\) \((w\_0)\)\[LongRightArrow]W\)\), TextForm], 
    FormBox[
      RowBox[{
        FormBox[
          \(Conjecture : \ W\ is\ an\ 8 - point\ for\ the\ parametrized\),
          "TextForm"], " ", \(S\_8\), " ", "action", " ", \(G\_w\%K\)}], 
      TextForm]}], "Text",
  FontFamily->"Helvetica",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[Table[fKIt[\([i]\)] - fKIt[\([i - 1]\)], {i, \(-2\), \(-1\)}]]\)], 
  "Input"],

Cell[BoxData[
    \({{\(-6.18934880583087831`*^-149\) - 1.99354735238323481`*^-149\ I, 
        \(-3.9344368261208924`*^-11\) - 9.87301820531775753`*^-11\ I, 
        \(-9.29906821083278778`*^-10\) - 2.16456621835384099`*^-9\ I, 
        \(-9.93412230622785941`*^-9\) - 2.12733170181531239`*^-8\ I, 
        \(-5.66097923277740644`*^-8\) - 1.10530763885521765`*^-7\ I, 
        \(-1.73134639546853481`*^-7\) - 3.05465381700218641`*^-7\ I, 
        \(-1.83274228851226776`*^-7\) - 2.88874111604065895`*^-7\ I}, {
        \(-2.69460050955209862`*^-144\) - 2.04089118392652535`*^-147\ I, 
        9.97761804452720291`*^-54 - 5.51352708238034772`*^-54\ I, 
        2.37366303908837661`*^-52 - 1.25427540415853`*^-52\ I, 
        2.54137234093413599`*^-51 - 1.28242214262265473`*^-51\ I, 
        1.4450513186166269`*^-50 - 6.95435855222846299`*^-51\ I, 
        4.39373334584905794`*^-50 - 2.01228940547126189`*^-50\ I, 
        4.60051053769216533`*^-50 - 2.0043312018030388`*^-50\ I}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(TextForm
    \`\(\(\(\(1)\) Obtain\ a\ candidate\ root\ for\ \(R\_K\) 
                  \(\((s)\) : \ \ \n\t\ \ evaluate\ the\ root - selector\), \ 
                \(J\_K\) \((W)\)\n2)\) Check\ that\ the\ candidate\ root\ is\ 
              a\ root\ of\ \(R\_K\) \((s)\)\n3)\)\ Obtain\ a\ candidate\ root
          \ for\ the\ general\ 
          \(quinitc : \n\t\ \ 
            apply\ \ linear\ Tschirnhaus\ transformations\)\n4)\) Check\ that
      \ the\ candidate\ root\ is\ a\ root\ of\ general\ octic\)], "Text",
  FontFamily->"Helvetica",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*1*) \nS8a6Root\  = JaKChooseEval[fKIt[\([\(-1\)]\)]]; \n
    N[S8a6Root]\n (*2*) \), 
    \(N[RaKChooseEval[S8a6Root]]\n (*3*) \), 
    \(GenRoot\  = \ \n
      GenToSt[S8a7ToStTrf[S8a6Root, \[Lambda]Choose], 
        GenCoeffChoose[\([1]\)]]; \nN[GenRoot]\n (*4*) \), 
    \(N[FuncEval[GenChoose, {x}, {GenRoot}]]\)}], "Input"],

Cell[BoxData[
    \(\(-9.33050087733898791`\) - 0.00343715083415854882`\ I\)], "Output"],

Cell[BoxData[
    \(\(0.`\[InvisibleSpace]\) + 0.`\ I\)], "Output"],

Cell[BoxData[
    \(\(-4.66272264441757489`\) + 98.5789654199799514`\ I\)], "Output"],

Cell[BoxData[
    \(\(0.`\[InvisibleSpace]\) + 0.`\ I\)], "Output"]
}, Open  ]],

Cell["Collect the roots", "Text",
  FontFamily->"Helvetica",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Union[AppendTo[RootList, N[GenRoot]]]\)], "Input"],

Cell[BoxData[
    \({\(-4.66272264441757489`\) + 98.5789654199799514`\ I}\)], "Output"]
}, Open  ]],

Cell["If no roots yet", "Text",
  FontFamily->"Helvetica",
  FontSize->14,
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(\(RootList = {}; \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NSolve[GenChoose == 0]\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] \(-4.66272264441757489`\) + 98.5789654199799514`\ I}, {
        x \[Rule] \(-0.749543611124125952`\) + 0.549303531334605033`\ I}, {
        x \[Rule] \(-0.590288681003480952`\) - 0.00442396493073553909`\ I}, {
        x \[Rule] \(-0.574689557410945894`\) - 0.520615789723779887`\ I}, {
        x \[Rule] 
          \(0.194609058717116631`\[InvisibleSpace]\) - 
            0.862483694757392882`\ I}, {
        x \[Rule] 
          \(0.198149342549391533`\[InvisibleSpace]\) + 
            0.832256705161943521`\ I}, {
        x \[Rule] 
          \(0.831694131531966185`\[InvisibleSpace]\) + 
            0.248312516323140775`\ I}, {
        x \[Rule] 
          \(1.59214909303727942`\[InvisibleSpace]\) - 
            0.701622983160234436`\ I}}\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 544}},
WindowSize->{470, 445},
WindowMargins->{{1, Automatic}, {Automatic, 5}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 212, 3, 170, "Input"],
Cell[1924, 54, 107, 3, 34, "Text"],
Cell[2034, 59, 607, 12, 310, "Input"],
Cell[2644, 73, 172, 5, 34, "Text"],
Cell[2819, 80, 155, 2, 50, "Input"],
Cell[2977, 84, 104, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[3106, 91, 206, 4, 90, "Input"],
Cell[3315, 97, 140, 2, 48, "Output"]
}, Open  ]],
Cell[3470, 102, 197, 6, 54, "Text"],
Cell[3670, 110, 72, 1, 30, "Input"],
Cell[3745, 113, 178, 7, 74, "Text"],
Cell[3926, 122, 190, 5, 90, "Input"],
Cell[4119, 129, 127, 3, 50, "Input"],
Cell[4249, 134, 218, 7, 74, "Text"],

Cell[CellGroupData[{
Cell[4492, 145, 364, 7, 230, "Input"],
Cell[4859, 154, 813, 15, 86, "Output"],
Cell[5675, 171, 590, 9, 124, "Output"],
Cell[6268, 182, 476, 7, 86, "Output"]
}, Open  ]],
Cell[6759, 192, 444, 9, 108, "Text"],

Cell[CellGroupData[{
Cell[7228, 205, 1038, 20, 503, "Input"],
Cell[8269, 227, 566, 12, 67, "Output"],
Cell[8838, 241, 104, 2, 29, "Output"]
}, Open  ]],
Cell[8957, 246, 719, 13, 149, "Text"],

Cell[CellGroupData[{
Cell[9701, 263, 2688, 58, 1148, "Input"],
Cell[12392, 323, 714, 13, 86, "Output"]
}, Open  ]],
Cell[13121, 339, 112, 6, 58, "Text"],
Cell[13236, 347, 110, 2, 50, "Input"],
Cell[13349, 351, 117, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[13491, 358, 238, 5, 130, "Input"],
Cell[13732, 365, 492, 8, 67, "Output"]
}, Open  ]],
Cell[14239, 376, 107, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[14371, 383, 167, 3, 130, "Input"],
Cell[14541, 388, 2159, 33, 257, "Output"]
}, Open  ]],
Cell[16715, 424, 110, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[16850, 431, 196, 3, 150, "Input"],
Cell[17049, 436, 2219, 33, 238, "Output"]
}, Open  ]],
Cell[19283, 472, 456, 13, 55, "Text"],

Cell[CellGroupData[{
Cell[19764, 489, 100, 2, 30, "Input"],
Cell[19867, 493, 996, 14, 257, "Output"]
}, Open  ]],
Cell[20878, 510, 616, 12, 127, "Text"],

Cell[CellGroupData[{
Cell[21519, 526, 352, 7, 250, "Input"],
Cell[21874, 535, 88, 1, 29, "Output"],
Cell[21965, 538, 67, 1, 29, "Output"],
Cell[22035, 541, 85, 1, 29, "Output"],
Cell[22123, 544, 67, 1, 29, "Output"]
}, Open  ]],
Cell[22205, 548, 108, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[22338, 555, 70, 1, 30, "Input"],
Cell[22411, 558, 87, 1, 29, "Output"]
}, Open  ]],
Cell[22513, 562, 106, 3, 34, "Text"],
Cell[22622, 567, 52, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[22699, 572, 55, 1, 30, "Input"],
Cell[22757, 575, 792, 16, 86, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

